"
I define a [Mustache][1] template and how it is used to create
derivate output files combining it with particular data sources.

[1]: https://mustache.github.io/
"
Class {
	#name : #BreaTemplate,
	#superclass : #Object,
	#instVars : [
		'template',
		'data',
		'location',
		'queries',
		'outputs'
	],
	#category : #Brea
}

{ #category : #adding }
BreaTemplate >> addDataSourceNamed: name with: source [ 
	self 
		data at: name put: source.
	self data.
]

{ #category : #accessing }
BreaTemplate >> data [
	^ data ifNil: [ data := Dictionary new ]
]

{ #category : #accessing }
BreaTemplate >> data: aDictionary [
	"Each item in the dictionary is a unique alias (as key) and a data location (as value),
	usually on the web.
	Alias and locations are used later to define data queries to feed into templates."
	data := aDictionary
]

{ #category : #accessing }
BreaTemplate >> location [
	^ location
]

{ #category : #accessing }
BreaTemplate >> location: aFolderPath [
	"This is the place where a template and its derivate files are located.
	A shared location is an easy approach to start with and creates more explicit 
	relation between derived files and templates.
	Eventually some re-mapping or re-routing could be used so templates and their outputs
	could be further apart."
	location := aFolderPath
]

{ #category : #accessing }
BreaTemplate >> outputs [
	^ outputs
]

{ #category : #accessing }
BreaTemplate >> outputs: fileNamesList [
	"fileNamesList contain the files which are derived from the template."
	outputs := fileNamesList
]

{ #category : #accessing }
BreaTemplate >> queries [
	^ queries ifNil: [ queries := Dictionary new ]
]

{ #category : #accessing }
BreaTemplate >> queries: aDictionary [
	"aDictionary contains the alias for the query as key and a block that will be executed
	on a particular data source, as value."
	queries := aDictionary 
]

{ #category : #accessing }
BreaTemplate >> template [
	^ template
]

{ #category : #accessing }
BreaTemplate >> template: aFileName [
	"I provide the name of the mustache base template.
	The file can have any name, but by convention they end in '.mus.html' 'mus.md' and
	so on."
	template := aFileName
]
