"
I model a wiki page of a Brea site.
"
Class {
	#name : #BreaWikiPage,
	#superclass : #Object,
	#instVars : [
		'shortName',
		'template',
		'templateData',
		'namespace',
		'bodyTag'
	],
	#category : #Brea
}

{ #category : #operation }
BreaWikiPage >> bodyContentsAsHTML [
	| sourcePage |
	self markdownFile ifNil: [ ^ self ].
	sourcePage := FileLocator temp / 'wikiPage.md'.
	MarkupFile exportAsFileOn: sourcePage containing:  self markdownFile contents.
	^ Pandoc markdownToHtml: sourcePage 
]

{ #category : #accessing }
BreaWikiPage >> bodyTag [
	^ bodyTag
]

{ #category : #accessing }
BreaWikiPage >> bodyTag: aString [
	"I represent the Mustache Template tag used to denote the body part of a page.
	While the metadata is self describing via YAML metadata blocks in Markddown, so
	they map where ever they are needed in a template, the Markdown file that will be converted
	in HTML via a template doesn't know which part should occupy once the conversion is done.
	I provide such knowledge. So if a page template puts the body content under the mustache tag 
	{{content}}, I should use bodyTag: 'content'.
	bodyTag: is template dependant."
	bodyTag := aString
]

{ #category : #'as yet unclassified' }
BreaWikiPage >> exportAsHTML [
	| htmlContents allActions semaphore result |
	self shortName ifNil: [ ^ self ].
	self template ifNil: [ ^ self ].
	self bodyTag ifNil: [ ^ self ].
	allActions := TKTFuture all: { 
		[ self populateMetadata ] future.
		[ self populateBodyAs: self bodyTag ] future.
	}.
	semaphore := Semaphore new.
	allActions onSuccessDo: [ :values | 
		result := values last.
		semaphore signal.
	].
	semaphore wait.
	htmlContents := (MustacheTemplate on: result templateFile contents) value: result templateData.
	^ MarkupFile exportAsFileOn: self namespace / (self shortName, '.html' ) containing: htmlContents 
]

{ #category : #'as yet unclassified' }
BreaWikiPage >> htmlContents [
	self shortName ifNil: [ ^ self ].
	self template ifNil: [ ^ self ].
	^ (MustacheTemplate on: self templateFile contents) value: self templateData.
]

{ #category : #operation }
BreaWikiPage >> markdownFile [
	| localFile | 
	self namespace ifNil: [ ^ self ].
	self shortName ifNil: [ ^ self ].
	localFile := self namespace / (self shortName, '.md').
	localFile exists ifFalse: [ ^ self ].
	^ Markdown fromFile: localFile
]

{ #category : #accessing }
BreaWikiPage >> namespace [
	^ namespace
]

{ #category : #accessing }
BreaWikiPage >> namespace: folderFileReference [
	namespace := folderFileReference
]

{ #category : #'as yet unclassified' }
BreaWikiPage >> populateBodyAs: key [
	| allActions result semaphore |
	allActions := TKTFuture all: { 
		[ self bodyContentsAsHTML ] future.
	}.
	semaphore := Semaphore new.
	allActions onSuccessDo: [ :values | 
		result := values last.
		semaphore signal ].
	semaphore wait.
	self templateData at: key put: result contents.
	^ self.
]

{ #category : #operation }
BreaWikiPage >> populateMetadata [
	self markdownFile metadata keysAndValuesDo: [ :key :value |
		self templateData at: key put: value
	].
	^ templateData
]

{ #category : #accessing }
BreaWikiPage >> shortName [
	^ shortName
]

{ #category : #accessing }
BreaWikiPage >> shortName: aString [
	shortName := aString
]

{ #category : #accessing }
BreaWikiPage >> template [
	^ template
]

{ #category : #accessing }
BreaWikiPage >> template: mustacheFileName [
	"Usually templates and their pages are located in the same folder."
	template := mustacheFileName 
]

{ #category : #accessing }
BreaWikiPage >> templateData [
	^ templateData ifNil: [ templateData := Dictionary new ]
]

{ #category : #accessing }
BreaWikiPage >> templateData: aDictionary [
	templateData := aDictionary
]

{ #category : #'as yet unclassified' }
BreaWikiPage >> templateFile [
	self namespace ifNil: [ ^ self ].
	self template ifNil: [ ^ self ].
	^ self namespace / self template
]
